:mod:`API`
----------------------------

``model_catalogs`` Python API
=============================

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation


Top-level API
*************

.. autosummary::
   :toctree: generated/

   model_catalogs.setup
   model_catalogs.find_availability
   model_catalogs.select_date_range


Paths available
***************

.. automodule:: model_catalogs
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


``model_catalogs``
******************

.. automodule:: model_catalogs.model_catalogs
  :members:
  :inherited-members:
  :undoc-members:
  :show-inheritance:


``utils``
*********

.. automodule:: model_catalogs.utils
  :members:
  :inherited-members:
  :undoc-members:
  :show-inheritance:


Transforming Datasets with ``process``
**************************************

.. automodule:: model_catalogs.process
  :members:
  :inherited-members:
  :undoc-members:
  :show-inheritance:
